# Scale RS232 Reader v2.2 Ultra Large Display

**Electronic Scale Data Reader via RS232/Serial Port - Simultaneous Dual Scale Display**

## 🎯 Key Features v2.2

- ✅ **Dual Scale Display**: Monitor 2 scales simultaneously on the same screen
- ✅ **Ultra Large Weight Display**: 84pt font size for easy reading from distance
- ✅ **No Tab Switching**: Streamlined interface saves time and effort
- ✅ **Real-time Monitoring**: Live weight data updates
- ✅ **Data Logging**: Automatic CSV history logging
- ✅ **Clean UI**: Minimalist interface with optimized window size
- ✅ **Robust Error Handling**: Reliable connection management
- ✅ **Professional Monitoring**: Designed for industrial and commercial use

## 🚀 Installation & Usage

### Method 1: Run from Executable (Recommended)

1. **Build the executable:**
   ```bash
   build_production.bat
   ```

2. **Run the application:**
   ```bash
   dist\ScaleRS232Reader_v2.exe
   ```

### Method 2: Run from Source Code

1. **Install dependencies:**
   ```bash
   pip install -r requirements.txt
   ```

2. **Run the application:**
   ```bash
   python main.py
   ```

## 📖 User Guide

### 1. **Scale Connection:**
   - Select COM port for each scale from dropdown menu
   - Choose baud rate (default: 9600)
   - Click "Connect" button for each scale individually

### 2. **Data Monitoring:**
   - **Both scales display simultaneously** on the same screen
   - Current weight with **ultra-large font** (84pt) for distant viewing
   - Real-time statistics (read count, min, max, average) below each scale
   - No cluttered history display - dedicated history viewer available

### 3. **Connection Management:**
   - Connect/disconnect each scale independently
   - "Disconnect All" button for quick shutdown
   - "Refresh COM Ports" to update available ports
   - Automatic error recovery and reconnection

### 4. **Data History:**
   - Automatic saving to `history/` directory
   - File format: `Scale_X_COMX_YYYYMMDD_HHMMSS.csv`
   - Click "View History" to open history folder
   - CSV format compatible with Excel and data analysis tools

## 🎨 Interface Layout v2.2

### **Simultaneous Dual Scale Display:**

## 🔧 System Requirements

- **Operating System**: Windows 7/8/10/11
- **Python**: 3.7+ (if running from source)
- **Dependencies**: pyserial 3.5
- **Display**: Minimum 1400x800 (recommended 1600x900+)
- **Hardware**: RS232/Serial port or USB-to-Serial adapter

## ⚙️ Technical Specifications

### **Supported Scale Protocols:**
- Standard RS232 serial communication
- Configurable baud rates: 1200, 2400, 4800, 9600, 19200, 38400
- Automatic weight data parsing from various scale formats
- Error detection and automatic reconnection

### **Data Logging:**
- CSV format with timestamps
- Separate files for each scale/session
- Automatic directory creation
- Compatible with Excel, Google Sheets, and data analysis tools

### **Performance:**
- Real-time updates with minimal CPU usage
- Memory optimized for continuous operation
- Smooth display refresh for professional monitoring
- Thread-safe serial communication

## ⚠️ Troubleshooting

### COM Port Connection Issues
- Verify scale is powered on and properly connected
- Check cable connections (RS232 or USB-to-Serial)
- Try different baud rates (9600 is most common)
- Ensure no other applications are using the same COM port
- Use Device Manager to verify COM port availability

### Data Reading Problems
- Check scale data format in console log
- Verify scale is configured to send continuous data
- Some scales require manual triggering for data transmission
- Ensure proper RS232 wiring (TX, RX, GND)

### Interface Display Issues
- Increase screen resolution or decrease Windows scaling
- Minimum display resolution: 1400x800
- For smaller screens, consider using Windows magnifier
- Ensure graphics drivers are up to date

### Performance Issues
- Close other resource-intensive applications
- Check Windows Task Manager for high CPU usage
- Restart application if memory usage grows excessively
- Verify USB-to-Serial driver installation

## 🔍 Data Format Examples

### **Supported Scale Output Formats:**
Standard Format:    +000123.45 kg
Compact Format:     123.45
With Units:         123.45 kg
With Status:        ST,GS,123.45 kg

### **CSV Log Format:**
```csv
Timestamp,Scale_ID,Weight,Unit,Raw_Data
2024-01-15 14:30:25,Scale_1,125.450,kg,+000125.45 kg
2024-01-15 14:30:26,Scale_1,125.480,kg,+000125.48 kg
```

## 📝 Version History

### **v2.2 Ultra Large Display:**
✅ **New Features:**
- **Simultaneous dual scale monitoring** on single screen
- **Ultra-large 84pt weight display** for distant visibility
- **Expanded window size** (1600x900) for better readability
- **Side-by-side layout** eliminates tab switching

✅ **UI/UX Improvements:**
- Removed cluttered scrolling history display
- Optimized layout for real-time monitoring
- Enhanced color scheme and spacing
- Intelligent status bar with combined information

✅ **Performance Enhancements:**
- Reduced CPU usage (no scrolling text widgets)
- Memory optimization for continuous operation
- Smoother real-time display updates
- Improved thread management

✅ **Professional Features:**
- Industrial-grade monitoring interface
- Robust error handling and recovery
